Module eager

Module eager 

Eager loading infrastructure for relationships.

This module provides the EagerLoader builder for configuring which relationships to load with a query. Eager loading fetches related objects in the same query using SQL JOINs.

Structs

EagerLoader
Builder for eager loading configuration.
IncludePath
A path to a relationship to include.

Functions

build_aliased_columns
Generate aliased column names for eager loading.
build_join_clause
Generate a JOIN clause for a relationship.
find_relationship
Find a relationship by name in a model’s RELATIONSHIPS.