WindowBuilder

Struct WindowBuilder 

pub struct WindowBuilder { /* private fields */ }
Builder for window functions with OVER clause.

Implementations

Source

impl WindowBuilder

pub fn partition_by(self, expr: impl Into<Expr>) -> Self

Add a PARTITION BY expression.

Can be called multiple times to partition by multiple columns.

pub fn partition_by_many(self, exprs: Vec<impl Into<Expr>>) -> Self

Add multiple PARTITION BY expressions at once.

pub fn order_by(self, order: OrderBy) -> Self

Add an ORDER BY clause within the window.

Can be called multiple times to order by multiple columns.

pub fn order_by_asc(self, expr: impl Into<Expr>) -> Self

Add ORDER BY with ascending direction.

pub fn order_by_desc(self, expr: impl Into<Expr>) -> Self

Add ORDER BY with descending direction.

pub fn rows_between( self, start: WindowFrameBound, end: WindowFrameBound, ) -> Self

Set frame specification: ROWS BETWEEN start AND end.

Example
// ROWS BETWEEN 2 PRECEDING AND CURRENT ROW
.rows_between(WindowFrameBound::Preceding(2), WindowFrameBound::CurrentRow)
pub fn rows(self, start: WindowFrameBound) -> Self

Set frame specification: ROWS start (no end bound).

Example
// ROWS UNBOUNDED PRECEDING
.rows(WindowFrameBound::UnboundedPreceding)
pub fn range_between( self, start: WindowFrameBound, end: WindowFrameBound, ) -> Self

Set frame specification: RANGE BETWEEN start AND end.

Example
// RANGE BETWEEN UNBOUNDED PRECEDING AND CURRENT ROW
.range_between(WindowFrameBound::UnboundedPreceding, WindowFrameBound::CurrentRow)
pub fn range(self, start: WindowFrameBound) -> Self

Set frame specification: RANGE start (no end bound).

pub fn groups_between( self, start: WindowFrameBound, end: WindowFrameBound, ) -> Self

Set frame specification: GROUPS BETWEEN start AND end (PostgreSQL 11+).

pub fn build(self) -> Expr

Finalize and build the window expression.