SetOpType

Enum SetOpType 

pub enum SetOpType {
    Union,
    UnionAll,
    Intersect,
    IntersectAll,
    Except,
    ExceptAll,
}
Type of set operation.

Variants



Union

UNION - combines results, removes duplicates



UnionAll

UNION ALL - combines results, keeps duplicates



Intersect

INTERSECT - returns common rows, removes duplicates



IntersectAll

INTERSECT ALL - returns common rows, keeps duplicates



Except

EXCEPT - returns rows in first query not in second, removes duplicates



ExceptAll

EXCEPT ALL - returns rows in first query not in second, keeps duplicates

Implementations

Source

impl SetOpType

pub const fn as_sql(&self) -> &'static str

Get the SQL keyword for this set operation.