pub struct InsertBuilder<'a, M: Model> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, M: Model> InsertBuilder<'a, M>
impl<'a, M: Model> InsertBuilder<'a, M>
Sourcepub fn returning(self) -> Self
pub fn returning(self) -> Self
Add RETURNING * clause to return the inserted row.
Use with execute_returning() to get the inserted row.
Sourcepub fn on_conflict_do_nothing(self) -> Self
pub fn on_conflict_do_nothing(self) -> Self
Handle conflicts by doing nothing (PostgreSQL ON CONFLICT DO NOTHING).
This allows the insert to silently succeed even if it would violate a unique constraint.
Sourcepub fn on_conflict_do_update(self, columns: &[&str]) -> Self
pub fn on_conflict_do_update(self, columns: &[&str]) -> Self
Sourcepub fn on_conflict_target_do_update(
self,
target: &[&str],
columns: &[&str],
) -> Self
pub fn on_conflict_target_do_update( self, target: &[&str], columns: &[&str], ) -> Self
Handle conflicts by updating columns with a specific conflict target.
Arguments
target- The columns that form the unique constraint to matchcolumns- The columns to update on conflict
Sourcepub fn build(&self) -> (String, Vec<Value>)
pub fn build(&self) -> (String, Vec<Value>)
Build the INSERT SQL and parameters with default dialect (Postgres).
Sourcepub fn build_with_dialect(&self, dialect: Dialect) -> (String, Vec<Value>)
pub fn build_with_dialect(&self, dialect: Dialect) -> (String, Vec<Value>)
Build the INSERT SQL and parameters with specific dialect.
Sourcepub async fn execute<C: Connection>(
self,
cx: &Cx,
conn: &C,
) -> Outcome<i64, Error>
pub async fn execute<C: Connection>( self, cx: &Cx, conn: &C, ) -> Outcome<i64, Error>
Execute the INSERT and return the inserted ID.
Sourcepub async fn execute_returning<C: Connection>(
self,
cx: &Cx,
conn: &C,
) -> Outcome<Option<Row>, Error>
pub async fn execute_returning<C: Connection>( self, cx: &Cx, conn: &C, ) -> Outcome<Option<Row>, Error>
Execute the INSERT with RETURNING and get the inserted row.
This automatically adds RETURNING * and returns the full row.