pub struct WindowBuilder { /* private fields */ }Expand description
Builder for window functions with OVER clause.
Implementations
Sourceimpl WindowBuilder
impl WindowBuilder
Sourcepub fn partition_by(self, expr: impl Into<Expr>) -> Self
pub fn partition_by(self, expr: impl Into<Expr>) -> Self
Add a PARTITION BY expression.
Can be called multiple times to partition by multiple columns.
Sourcepub fn partition_by_many(self, exprs: Vec<impl Into<Expr>>) -> Self
pub fn partition_by_many(self, exprs: Vec<impl Into<Expr>>) -> Self
Add multiple PARTITION BY expressions at once.
Sourcepub fn order_by(self, order: OrderBy) -> Self
pub fn order_by(self, order: OrderBy) -> Self
Add an ORDER BY clause within the window.
Can be called multiple times to order by multiple columns.
Sourcepub fn order_by_asc(self, expr: impl Into<Expr>) -> Self
pub fn order_by_asc(self, expr: impl Into<Expr>) -> Self
Add ORDER BY with ascending direction.
Sourcepub fn order_by_desc(self, expr: impl Into<Expr>) -> Self
pub fn order_by_desc(self, expr: impl Into<Expr>) -> Self
Add ORDER BY with descending direction.
Sourcepub fn rows_between(
self,
start: WindowFrameBound,
end: WindowFrameBound,
) -> Self
pub fn rows_between( self, start: WindowFrameBound, end: WindowFrameBound, ) -> Self
Sourcepub fn rows(self, start: WindowFrameBound) -> Self
pub fn rows(self, start: WindowFrameBound) -> Self
Sourcepub fn range_between(
self,
start: WindowFrameBound,
end: WindowFrameBound,
) -> Self
pub fn range_between( self, start: WindowFrameBound, end: WindowFrameBound, ) -> Self
Sourcepub fn range(self, start: WindowFrameBound) -> Self
pub fn range(self, start: WindowFrameBound) -> Self
Set frame specification: RANGE start (no end bound).
Sourcepub fn groups_between(
self,
start: WindowFrameBound,
end: WindowFrameBound,
) -> Self
pub fn groups_between( self, start: WindowFrameBound, end: WindowFrameBound, ) -> Self
Set frame specification: GROUPS BETWEEN start AND end (PostgreSQL 11+).