pub enum SetOpType {
Union,
UnionAll,
Intersect,
IntersectAll,
Except,
ExceptAll,
}Expand description
Type of set operation.
Variants
Union
UNION - combines results, removes duplicates
UnionAll
UNION ALL - combines results, keeps duplicates
Intersect
INTERSECT - returns common rows, removes duplicates
IntersectAll
INTERSECT ALL - returns common rows, keeps duplicates
Except
EXCEPT - returns rows in first query not in second, removes duplicates
ExceptAll
EXCEPT ALL - returns rows in first query not in second, keeps duplicates
Implementations